@@ -20,6 +20,7 @@
 import os
 import os.path
 import sys
+import platform
 
 CLARA_AGX_XAVIER = 'CLARA_AGX_XAVIER'
 JETSON_NX = 'JETSON_NX'
@@ -27,6 +28,8 @@ JETSON_XAVIER = 'JETSON_XAVIER'
 JETSON_TX2 = 'JETSON_TX2'
 JETSON_TX1 = 'JETSON_TX1'
 JETSON_NANO = 'JETSON_NANO'
+JETSON_TX2_NX='JETSON_TX2_NX'
+JETSON_ORIN='JETSON_ORIN'
 
 # These arrays contain tuples of all the relevant GPIO data for each Jetson
 # Platform. The fields are:
@@ -45,11 +48,41 @@ JETSON_NANO = 'JETSON_NANO'
 # The values are used to generate dictionaries that map the corresponding pin
 # mode numbers to the Linux GPIO pin number and GPIO chip directory
 
+JETSON_ORIN_PIN_DEFS = [
+    ({164: 106}, {164:  'PQ.06'}, "2200000.gpio", 7, 4, 'GPIO40', 'GP66', None, None),
+    # Output-only (due to base board)
+    ({164: 112}, {164:  'PR.04'}, "2200000.gpio", 11, 17, 'UART1_RTS', 'GP72_UART1_RTS_N', None, None),
+    ({164:  50}, {164:  'PH.07'}, "2200000.gpio", 12, 18, 'I2S2_CLK', 'GP122', None, None),
+    ({164:  108}, {164:  'PR.00'}, "2200000.gpio", 13, 27, 'GPIO32', 'GP58', None, None),
+    ({164:  85}, {164:  'PN.01'}, "2200000.gpio", 15, 22, 'GPIO27', 'GP88_PWM1', '3280000.pwm', 0),
+    ({32:   9}, { 32: 'PBB.01'}, "c2f0000.gpio", 16, 23, 'GPIO8', 'GP25', None, None),
+    ({164:  43}, {164:  'PH.00'}, "2200000.gpio", 18, 24, 'GPIO35', 'GP115', '32c0000.pwm', 0),
+    ({164: 135}, {164:  'PZ.05'}, "2200000.gpio", 19, 10, 'SPI1_MOSI', 'GP49_SPI1_MOSI', None, None),
+    ({164: 134}, {164:  'PZ.04'}, "2200000.gpio", 21, 9, 'SPI1_MISO', 'GP48_SPI1_MISO', None, None),
+    ({164: 96}, {164:  'PP.04'}, "2200000.gpio", 22, 25, 'GPIO17', 'GP56', None, None),
+    ({164: 133}, {164:  'PZ.03'}, "2200000.gpio", 23, 11, 'SPI1_CLK', 'GP47_SPI1_CLK', None, None),
+    ({164: 136}, {164:  'PZ.06'}, "2200000.gpio", 24, 8, 'SPI1_CS0_N', 'GP50_SPI1_CS0_N', None, None),
+    ({164: 137}, {164:  'PZ.07'}, "2200000.gpio", 26, 7, 'SPI1_CS1_N', 'GP51_SPI1_CS1_N', None, None),
+    ({ 32:   1}, { 32: 'PAA.01'}, "c2f0000.gpio", 29, 5, 'CAN0_DIN', 'GP18_CAN0_DIN', None, None),
+    ({ 32:   0}, { 32: 'PAA.00'}, "c2f0000.gpio", 31, 6, 'CAN0_DOUT', 'GP17_CAN0_DOUT', None, None),
+    ({ 32:  8}, { 32: 'PBB.00'}, "c2f0000.gpio", 32, 12, 'GPIO9', 'GP26', None, None),
+    ({ 32:   2}, { 32: 'PAA.02'}, "c2f0000.gpio", 33, 13, 'CAN1_DOUT', 'GP19_CAN1_DOUT', None, None),
+    ({164: 53}, {164:  'PI.02'}, "2200000.gpio", 35, 19, 'I2S2_FS', 'GP125', None, None),
+    ({164: 113}, {164:  'PR.05'}, "2200000.gpio", 36, 16, 'UART1_CTS', 'GP73_UART1_CTS_N', None, None),
+    ({ 32:   3}, { 32: 'PAA.03'}, "c2f0000.gpio", 37, 26, 'CAN1_DIN', 'GP20_CAN1_DIN', None, None),
+    ({164:  52}, {164:  'PI.01'}, "2200000.gpio", 38, 20, 'I2S2_DIN', 'GP124', None, None),
+    ({164:  51}, {164:  'PI.00'}, "2200000.gpio", 40, 21, 'I2S2_DOUT', 'GP123', None, None)
+]
+
+compats_jetson_orins = (
+    'nvidia,p3737-0000+p3701-0000',
+)
+
 CLARA_AGX_XAVIER_PIN_DEFS = [
     ({224: 134, 169: 106}, {169:  'PQ.06'}, "2200000.gpio", 7, 4, 'MCLK05', 'SOC_GPIO42', None, None),
     ({224: 140, 169: 112}, {169:  'PR.04'}, "2200000.gpio", 11, 17, 'UART1_RTS', 'UART1_RTS', None, None),
     ({224:  63, 169:  51}, {169:  'PH.07'}, "2200000.gpio", 12, 18, 'I2S2_CLK', 'DAP2_SCLK', None, None),
-    ({224: 124, 169:  96}, {169:  'PP.00'}, "2200000.gpio", 13, 27, 'GPIO32', 'SOC_GPIO04', None, None),
+    ({224: 124, 169:  96}, {169:  'PP.04'}, "2200000.gpio", 13, 27, 'GPIO32', 'SOC_GPIO04', None, None),
     # Older versions of L4T don't enable this PWM controller in DT, so this PWM
     # channel may not be available.
     ({224: 105, 169:  84}, {169:  'PN.01'}, "2200000.gpio", 15, 22, 'GPIO27', 'SOC_GPIO54', '3280000.pwm', 0),
@@ -138,6 +171,36 @@ compats_xavier = (
     'nvidia,p2972-0000',
     'nvidia,p2972-0006',
     'nvidia,jetson-xavier',
+    'nvidia,galen-industrial',
+    'nvidia,jetson-xavier-industrial',
+)
+
+JETSON_TX2_NX_PIN_DEFS = [
+    ({192:  76, 140: 66}, {140:  'PJ.04'}, "2200000.gpio", 7, 4, 'GPIO09', 'AUD_MCLK', None, None),
+    ({64: 28, 47: 23}, {47:  'PW.04'}, "c2f0000.gpio", 11, 17, 'UART1_RTS', 'UART3_RTS', None, None),
+    ({192:  72, 140: 62}, {140:  'PJ.00'}, "2200000.gpio", 12, 18, 'I2S0_SCLK', 'DAP1_SCLK', None, None),
+    ({64:  17, 47: 12}, {47:  'PV.01'}, "c2f0000.gpio", 13, 27, 'SPI1_SCK', 'GPIO_SEN1', None, None),
+    ({192:  18,  140: 16}, {140: 'PC.02'}, "2200000.gpio", 15, 22, 'GPIO12', 'DAP2_DOUT', None, None),
+    ({192: 19, 140: 17}, {140:  'PC.03'}, "2200000.gpio", 16, 23, 'SPI1_CS1', 'DAP2_DIN', None, None),
+    ({64: 20, 47: 15}, {47:  'PV.04'}, "c2f0000.gpio", 18, 24, 'SPI1_CS0', 'GPIO_SEN4', None, None),
+    ({192: 58, 140:  49}, {140:  'PH.02'}, "2200000.gpio", 19, 10, 'SPI0_MOSI', 'GPIO_WAN7', None, None),
+    ({192: 57, 140: 48}, {140:  'PH.01'}, "2200000.gpio", 21, 9, 'SPI0_MISO', 'GPIO_WAN6', None, None),
+    ({64: 18, 47: 13}, {47:  'PV.02'}, "c2f0000.gpio", 22, 25, 'SPI1_MISO', 'GPIO_SEN2', None, None),
+    ({192: 56, 140:  47}, {140:  'PH.00'}, "2200000.gpio", 23, 11, 'SPI1_CLK', 'GPIO_WAN5', None, None),
+    ({192: 59, 140: 50}, {140:  'PH.03'}, "2200000.gpio", 24, 8, 'SPI0_CS0', 'GPIO_WAN8', None, None),
+    ({192: 163, 140: 130}, {140:  'PY.03'}, "2200000.gpio", 26, 7, 'SPI0_CS1', 'GPIO_MDM4', None, None),
+    ({192: 105, 140: 86}, {140:  'PN.01'}, "2200000.gpio", 29, 5, 'GPIO01', 'GPIO_CAM2', None, None),
+    ({64: 50, 47: 41}, {47:  'PEE.02'}, "c2f0000.gpio", 31, 6, 'GPIO11', 'TOUCH_CLK', None, None),
+    ({64: 8, 47: 5}, {47:  'PU.00'}, "c2f0000.gpio", 32, 12, 'GPIO07', 'GPIO_DIS0', '3280000.pwm', 0),
+    ({64: 13, 47: 10}, {47:  'PU.05'}, "c2f0000.gpio", 33, 13, 'GPIO13', 'GPIO_DIS5', '32a0000.pwm', 0),
+    ({192: 75, 140: 65}, {140:  'PJ.03'}, "2200000.gpio", 35, 19, 'I2S0_FS', 'DAP1_FS', None, None),
+    ({64: 29, 47: 24}, {47:  'PW.05'}, "c2f0000.gpio", 36, 16, 'UART1_CTS', 'UART3_CTS', None, None),
+    ({64: 19, 47: 14}, {47:  'PV.03'}, "c2f0000.gpio", 37, 26, 'SPI1_MOSI', 'GPIO_SEN3', None, None),
+    ({192: 74, 140: 64}, {140:  'PJ.02'}, "2200000.gpio", 38, 20, 'I2S0_DIN', 'DAP1_DIN', None, None),
+    ({192:  73, 140:  63}, {140:  'PJ.01'}, "2200000.gpio", 40, 21, 'I2S0_DOUT', 'DAP1_DOUT', None, None)
+]
+compats_tx2_nx = (
+    'nvidia,p3509-0000+p3636-0001',
 )
 
 JETSON_TX2_PIN_DEFS = [
@@ -243,6 +306,17 @@ compats_nano = (
 )
 
 jetson_gpio_data = {
+    JETSON_ORIN: (
+        JETSON_ORIN_PIN_DEFS,
+        {
+            'P1_REVISION': 1,
+            'RAM': '32768M',
+            'REVISION': 'Unknown',
+            'TYPE': 'JETSON_ORIN',
+            'MANUFACTURER': 'NVIDIA',
+            'PROCESSOR': 'A78AE'
+        }
+    ),
     CLARA_AGX_XAVIER: (
         CLARA_AGX_XAVIER_PIN_DEFS,
         {
@@ -276,6 +350,17 @@ jetson_gpio_data = {
             'PROCESSOR': 'ARM Carmel'
         }
     ),
+    JETSON_TX2_NX: (
+        JETSON_TX2_NX_PIN_DEFS,
+        {
+            'P1_REVISION': 1,
+            'RAM': '4096M',
+            'REVISION': 'Unknown',
+            'TYPE': 'Jetson TX2 NX',
+            'MANUFACTURER': 'NVIDIA',
+            'PROCESSOR': 'ARM A57 + Denver'
+        }
+    ),
     JETSON_TX2: (
         JETSON_TX2_PIN_DEFS,
         {
@@ -339,6 +424,8 @@ def get_data():
     def find_pmgr_board(prefix):
         global ids_warned
         if not os.path.exists(ids_path):
+            if platform.uname()[2].startswith("5"):
+                return None
             if not ids_warned:
                 ids_warned = True
                 msg = """\
@@ -375,6 +462,9 @@ WARNING: and in fact is unlikely to work correctly.
     elif matches(compats_clara_agx_xavier):
         model = CLARA_AGX_XAVIER
         warn_if_not_carrier_board('3900')
+    elif matches(compats_tx2_nx):
+        model = JETSON_TX2_NX
+        warn_if_not_carrier_board('3509')
     elif matches(compats_xavier):
         model = JETSON_XAVIER
         warn_if_not_carrier_board('2822')
@@ -391,6 +481,8 @@ WARNING: and in fact is unlikely to work correctly.
     elif matches(compats_nx):
         model = JETSON_NX
         warn_if_not_carrier_board('3509', '3449')
+    elif matches(compats_jetson_orins):
+        model = JETSON_ORIN
     else:
         raise Exception('Could not determine Jetson model')
 
